@@ -2,9 +2,15 @@ import json
 from base64 import b64encode
 
 
-def create_update_invocation_file(contract, nef_file_path, manifest_file_path, operation='update'):
+def create_update_invocation_file(
+        contract_name,
+        nef_file_path,
+        manifest_file_path,
+        operation='update'
+) -> str:
+    """  """
     invocation_dict = {
-        'contract': contract,
+        'contract': contract_name,
         'operation': operation,
     }
 
@@ -13,15 +19,15 @@ def create_update_invocation_file(contract, nef_file_path, manifest_file_path, o
     with open(nef_file_path, 'rb') as file:
         raw_bytes = file.read()
         args.append({
-            'type': 'ByteString',
-            'value': b64encode(raw_bytes).decode('ascii'),
+            'type': 'ByteArray',
+            'value': raw_bytes.hex(),
         })
 
     with open(manifest_file_path, 'rb') as file:
         raw_bytes = file.read()
         args.append({
-            'type': 'ByteString',
-            'value': b64encode(raw_bytes).decode('ascii'),
+            'type': 'ByteArray',
+            'value': raw_bytes.hex(),
         })
 
     invocation_dict['args'] = args
